package
module
Version:
v0.2.1
Opens a new window with list of versions in this module.
Published: May 11, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
func If[T any](c bool, v T) (x ifs[T])
func Iif[T any](c bool, t, f T) (r T)
func MinMax[T cmp.Ordered](v, vMin, vMax, vDef T) (r T)
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.