package
module
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 11, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Pool[T any] struct {
}
func NewPool[T any](create func() T, reset func(T) (T, bool)) *Pool[T]
func (p *Pool[T]) Get() (value T, put func())
func (p *Pool[T]) Init(create func() T, reset func(T) (T, bool)) *Pool[T]
Source Files
¶
Click to show internal directories.
Click to hide internal directories.